@@ -4,7 +4,7 @@
 #' [data-FeatureCollection] of flat-topped hexagons
 #' ([data-Polygon] features) aligned in an "odd-q" vertical
 #' grid as described in Hexagonal Grids
-#' <http://www.redblobgames.com/grids/hexagons/>
+#' 
 #'
 #' @export
 #'
@@ -18,7 +18,7 @@
 #' lawn_hex_grid(c(-96,31,-84,40), 50, 'miles')
 #' lawn_hex_grid(c(-96,31,-84,40), 30, 'miles')
 lawn_hex_grid <- function(extent, cellWidth, units) {
-  ct$eval(sprintf("var hg = turf.hexGrid(%s, %s, '%s');", toj(extent),
-                  cellWidth, units))
+  ct$eval(sprintf("var hg = turf.hexGrid(%s, %s, {units:'%s'});",
+    toj(extent), cellWidth, units))
   as.fc(ct$get("hg"))
 }
