@@ -1,8 +1,7 @@
 #' Rewind
 #'
 #' Rewind (Multi)LineString or (Multi)Polygon outer ring counterclockwise
-#' and inner rings clockwise (Uses Shoelace Formula
-#' (<https://en.wikipedia.org/wiki/Shoelace_formula>)).
+#' and inner rings clockwise (Uses Shoelace Formula)
 #'
 #' @export
 #' @param x A [data-FeatureCollection] or [data-Feature] with
@@ -30,7 +29,7 @@
 lawn_rewind <- function(x, reverse = FALSE, mutate = FALSE, lint = FALSE) {
   if (!is.null(x)) lawnlint(x, lint)
   if (lint) is_type(x, type_top = c("FeatureCollection", "Feature"))
-  ct$eval(sprintf("var res = turf.rewind(%s, %s, %s);", convert(x),
-                  tolower(reverse), tolower(mutate)))
+  ct$eval(sprintf("var res = turf.rewind(%s, {reverse:%s, mutate:%s});",
+    convert(x), tolower(reverse), tolower(mutate)))
   as.fc(ct$get("res"))
 }
