@@ -1,18 +1,19 @@
 #' Spatial join of points and polygons
 #'
-#' Takes a set of \code{\link{data-Point}}'s and a set of
-#' \code{\link{data-Polygon}}'s and performs a spatial join
+#' Takes a set of [data-Point]'s and a set of
+#' [data-Polygon]'s and performs a spatial join.
 #'
 #' @export
-#' @param points Input \code{\link{data-Point}}
-#' @param polygons Input \code{\link{data-Polygon}} or
-#' \code{\link{data-MultiPolygon}}
-#' @param field property in polygons to add to joined Point features
-#' @param out_field property in points in which to store joined
-#' property from polygons
+#' @param points Input [data-FeatureCollection]<([data-Point])>
+#' @param polygons Input [data-FeatureCollection]<([data-Polygon])> or
+#' [data-FeatureCollection]<([data-MultiPolygon])>
+#' @param field Property in polygons to add to joined Point features.
+#' @param out_field Property in points in which to store joined
+#' property from polygons.
 #' @template lint
 #' @family joins
-#' @return points with containing_polyid property containing values from poly_id
+#' @return Points with containing_polyid property containing values
+#' from poly_id, as [data-FeatureCollection]<([data-Point])>
 #' @examples
 #' bbox <- c(0, 0, 10, 10)
 #' pts <- lawn_random(n = 30, bbox = bbox)
@@ -28,6 +29,12 @@ lawn_tag <- function(points, polygons, field, out_field, lint = FALSE) {
   points <- convert(points)
   polygons <- convert(polygons)
   lawnlint(list(points, polygons), lint)
+  if (lint) {
+    is_type(points, "FeatureCollection")
+    is_type(polygons, "FeatureCollection")
+  }
+  assert(field, "character")
+  assert(out_field, "character")
   ct$eval(sprintf("var xx = turf.tag(%s, %s, '%s', '%s');",
                   points, polygons, field, out_field))
   as.fc(ct$get("xx"))
