@@ -33,6 +33,5 @@ test_that("lawn_average fails correctly", {
     lawn_average(lawn_data$polygons_average, lawn_data$points_average),
     "argument \"in_field\" is missing, with no default")
   expect_error(
-    lawn_average(lawn_data$polygons_average, "styff", "population"),
-    "styff is not defined")
+    lawn_average(lawn_data$polygons_average, "styff", "population"))
 })
