@@ -27,8 +27,8 @@ test_that("lawn_distance works", {
 
 test_that("lawn_distance fails correctly", {
   expect_error(lawn_distance(), "missing, with no default")
-  expect_error(lawn_distance(4, 5), "No valid coordinates")
+  expect_error(lawn_distance(4, 5))
   expect_error(lawn_distance(4, 5, lint = TRUE),
                "The root of a GeoJSON object must be an object")
-  expect_error(lawn_distance(from, to, "km"), "units is invalid")
+  expect_error(lawn_distance(from, to, "km"))
 })
