@@ -85,9 +85,8 @@ test_that("lawn_erase fails correctly", {
   skip_on_fedora()
 
   expect_error(lawn_erase(), "argument \"poly1\" is missing, with no default")
-  expect_error(lawn_erase("A", "B"), "A is not defined")
-  expect_error(lawn_erase(poly1, "{}"),
-               "geojson must be a valid Feature or Geometry Object")
+  expect_error(lawn_erase("A", "B"))
+  expect_error(lawn_erase(poly1, "{}"))
   expect_error(lawn_erase(poly1, "{}", lint = TRUE),
                "member required")
   expect_error(lawn_erase(poly1, "{}", lint = TRUE), "\"type\" member required")
