@@ -39,6 +39,6 @@ test_that("lawn_extent returns correct values", {
 
 test_that("lawn_extent fails correctly", {
   expect_error(lawn_extent(), "argument \"input\" is missing, with no default")
-  expect_error(lawn_extent(5), "Unknown Geometry Type")
+  expect_error(lawn_extent(5))
   expect_error(lawn_extent("{}", TRUE), "Line 1 - \"type\" member required")
 })
