@@ -27,7 +27,7 @@ test_that("lawn_kinks works", {
 test_that("lawn_kinks fails correctly", {
   expect_error(lawn_kinks(), "argument \"input\" is missing, with no default")
   expect_error(lawn_kinks(5, TRUE), "Line 0 - The root of a GeoJSON object must be an object")
-  expect_error(lawn_kinks("adfadfs"), "ReferenceError")
+  expect_error(lawn_kinks("adfadfs"))
 
   bad1 <- '{"type":"Featureadf","properties":{},"geometry":{"type":"Polygon","coordinates":[[[-12.034835,8.901183],[-12.060413,8.899826],[-12.03638,8.873199],[-12.059383,8.871418],[-12.034835,8.901183]]]}}'
   expect_error(lawn_kinks(bad1, TRUE), "The type Featureadf is unknown")
